
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TriangleAlert(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-triangle-alert'], 'items': [{'path': {'d': 'm21.73 18-8-14a2 2 0 0 0-3.48 0l-8 14A2 2 0 0 0 4 21h16a2 2 0 0 0 1.73-3'}}, {'path': {'d': 'M12 9v4'}}, {'path': {'d': 'M12 17h.01'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SearchSlash(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-search-slash'], 'items': [{'path': {'d': 'm13.5 8.5-5 5'}}, {'circle': {'cx': '11', 'cy': '11', 'r': '8'}}, {'path': {'d': 'm21 21-4.3-4.3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ServerOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-server-off'], 'items': [{'path': {'d': 'M7 2h13a2 2 0 0 1 2 2v4a2 2 0 0 1-2 2h-5'}}, {'path': {'d': 'M10 10 2.5 2.5C2 2 2 2.5 2 5v3a2 2 0 0 0 2 2h6z'}}, {'path': {'d': 'M22 17v-1a2 2 0 0 0-2-2h-1'}}, {'path': {'d': 'M4 14a2 2 0 0 0-2 2v4a2 2 0 0 0 2 2h16.5l1-.5.5.5-8-8H4z'}}, {'path': {'d': 'M6 18h.01'}}, {'path': {'d': 'm2 2 20 20'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquareM(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-m'], 'items': [{'path': {'d': 'M8 16V8.5a.5.5 0 0 1 .9-.3l2.7 3.599a.5.5 0 0 0 .8 0l2.7-3.6a.5.5 0 0 1 .9.3V16'}}, {'rect': {'x': '3', 'y': '3', 'width': '18', 'height': '18', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Gauge(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-gauge'], 'items': [{'path': {'d': 'm12 14 4-4'}}, {'path': {'d': 'M3.34 19a10 10 0 1 1 17.32 0'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Mails(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-mails'], 'items': [{'path': {'d': 'M17 19a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2v-8a2 2 0 0 1 1-1.732'}}, {'path': {'d': 'm22 5.5-6.419 4.179a2 2 0 0 1-2.162 0L7 5.5'}}, {'rect': {'x': '7', 'y': '3', 'width': '15', 'height': '12', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Bookmark(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bookmark'], 'items': [{'path': {'d': 'm19 21-7-4-7 4V5a2 2 0 0 1 2-2h10a2 2 0 0 1 2 2v16z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CornerUpRight(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-corner-up-right'], 'items': [{'path': {'d': 'm15 14 5-5-5-5'}}, {'path': {'d': 'M4 20v-7a4 4 0 0 1 4-4h12'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def RailSymbol(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-rail-symbol'], 'items': [{'path': {'d': 'M5 15h14'}}, {'path': {'d': 'M5 9h14'}}, {'path': {'d': 'm14 20-5-5 6-6-5-5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BookmarkCheck(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bookmark-check'], 'items': [{'path': {'d': 'm19 21-7-4-7 4V5a2 2 0 0 1 2-2h10a2 2 0 0 1 2 2Z'}}, {'path': {'d': 'm9 10 2 2 4-4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BatteryCharging(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-battery-charging'], 'items': [{'path': {'d': 'm11 7-3 5h4l-3 5'}}, {'path': {'d': 'M14.856 6H16a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2h-2.935'}}, {'path': {'d': 'M22 14v-4'}}, {'path': {'d': 'M5.14 18H4a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h2.936'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ReceiptTurkishLira(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-receipt-turkish-lira'], 'items': [{'path': {'d': 'M10 6.5v11a5.5 5.5 0 0 0 5.5-5.5'}}, {'path': {'d': 'm14 8-6 3'}}, {'path': {'d': 'M4 2v20l2-1 2 1 2-1 2 1 2-1 2 1 2-1 2 1V2l-2 1-2-1-2 1-2-1-2 1-2-1-2 1z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Clapperboard(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-clapperboard'], 'items': [{'path': {'d': 'M20.2 6 3 11l-.9-2.4c-.3-1.1.3-2.2 1.3-2.5l13.5-4c1.1-.3 2.2.3 2.5 1.3Z'}}, {'path': {'d': 'm6.2 5.3 3.1 3.9'}}, {'path': {'d': 'm12.4 3.4 3.1 4'}}, {'path': {'d': 'M3 11h18v8a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2Z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Crosshair(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-crosshair'], 'items': [{'circle': {'cx': '12', 'cy': '12', 'r': '10'}}, {'line': {'x1': '22', 'x2': '18', 'y1': '12', 'y2': '12'}}, {'line': {'x1': '6', 'x2': '2', 'y1': '12', 'y2': '12'}}, {'line': {'x1': '12', 'x2': '12', 'y1': '6', 'y2': '2'}}, {'line': {'x1': '12', 'x2': '12', 'y1': '22', 'y2': '18'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Nfc(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-nfc'], 'items': [{'path': {'d': 'M6 8.32a7.43 7.43 0 0 1 0 7.36'}}, {'path': {'d': 'M9.46 6.21a11.76 11.76 0 0 1 0 11.58'}}, {'path': {'d': 'M12.91 4.1a15.91 15.91 0 0 1 .01 15.8'}}, {'path': {'d': 'M16.37 2a20.16 20.16 0 0 1 0 20'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def RouteOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-route-off'], 'items': [{'circle': {'cx': '6', 'cy': '19', 'r': '3'}}, {'path': {'d': 'M9 19h8.5c.4 0 .9-.1 1.3-.2'}}, {'path': {'d': 'M5.2 5.2A3.5 3.53 0 0 0 6.5 12H12'}}, {'path': {'d': 'm2 2 20 20'}}, {'path': {'d': 'M21 15.3a3.5 3.5 0 0 0-3.3-3.3'}}, {'path': {'d': 'M15 5h-4.3'}}, {'circle': {'cx': '18', 'cy': '5', 'r': '3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Sunrise(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-sunrise'], 'items': [{'path': {'d': 'M12 2v8'}}, {'path': {'d': 'm4.93 10.93 1.41 1.41'}}, {'path': {'d': 'M2 18h2'}}, {'path': {'d': 'M20 18h2'}}, {'path': {'d': 'm19.07 10.93-1.41 1.41'}}, {'path': {'d': 'M22 22H2'}}, {'path': {'d': 'm8 6 4-4 4 4'}}, {'path': {'d': 'M16 18a4 4 0 0 0-8 0'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PawPrint(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-paw-print'], 'items': [{'circle': {'cx': '11', 'cy': '4', 'r': '2'}}, {'circle': {'cx': '18', 'cy': '8', 'r': '2'}}, {'circle': {'cx': '20', 'cy': '16', 'r': '2'}}, {'path': {'d': 'M9 10a5 5 0 0 1 5 5v3.5a3.5 3.5 0 0 1-6.84 1.045Q6.52 17.48 4.46 16.84A3.5 3.5 0 0 1 5.5 10Z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Battery(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-battery'], 'items': [{'path': {'d': 'M 22 14 L 22 10'}}, {'rect': {'x': '2', 'y': '6', 'width': '16', 'height': '12', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Send(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-send'], 'items': [{'path': {'d': 'M14.536 21.686a.5.5 0 0 0 .937-.024l6.5-19a.496.496 0 0 0-.635-.635l-19 6.5a.5.5 0 0 0-.024.937l7.93 3.18a2 2 0 0 1 1.112 1.11z'}}, {'path': {'d': 'm21.854 2.147-10.94 10.939'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Warehouse(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-warehouse'], 'items': [{'path': {'d': 'M18 21V10a1 1 0 0 0-1-1H7a1 1 0 0 0-1 1v11'}}, {'path': {'d': 'M22 19a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V8a2 2 0 0 1 1.132-1.803l7.95-3.974a2 2 0 0 1 1.837 0l7.948 3.974A2 2 0 0 1 22 8z'}}, {'path': {'d': 'M6 13h12'}}, {'path': {'d': 'M6 17h12'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Club(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-club'], 'items': [{'path': {'d': 'M17.28 9.05a5.5 5.5 0 1 0-10.56 0A5.5 5.5 0 1 0 12 17.66a5.5 5.5 0 1 0 5.28-8.6Z'}}, {'path': {'d': 'M12 17.66L12 22'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def UserRoundPlus(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-user-round-plus'], 'items': [{'path': {'d': 'M2 21a8 8 0 0 1 13.292-6'}}, {'circle': {'cx': '10', 'cy': '8', 'r': '5'}}, {'path': {'d': 'M19 16v6'}}, {'path': {'d': 'M22 19h-6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Scale(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-scale'], 'items': [{'path': {'d': 'M12 3v18'}}, {'path': {'d': 'm19 8 3 8a5 5 0 0 1-6 0zV7'}}, {'path': {'d': 'M3 7h1a17 17 0 0 0 8-2 17 17 0 0 0 8 2h1'}}, {'path': {'d': 'm5 8 3 8a5 5 0 0 1-6 0zV7'}}, {'path': {'d': 'M7 21h10'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FunnelX(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-funnel-x'], 'items': [{'path': {'d': 'M12.531 3H3a1 1 0 0 0-.742 1.67l7.225 7.989A2 2 0 0 1 10 14v6a1 1 0 0 0 .553.895l2 1A1 1 0 0 0 14 21v-7a2 2 0 0 1 .517-1.341l.427-.473'}}, {'path': {'d': 'm16.5 3.5 5 5'}}, {'path': {'d': 'm21.5 3.5-5 5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def EyeClosed(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-eye-closed'], 'items': [{'path': {'d': 'm15 18-.722-3.25'}}, {'path': {'d': 'M2 8a10.645 10.645 0 0 0 20 0'}}, {'path': {'d': 'm20 15-1.726-2.05'}}, {'path': {'d': 'm4 15 1.726-2.05'}}, {'path': {'d': 'm9 18 .722-3.25'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BellDot(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bell-dot'], 'items': [{'path': {'d': 'M10.268 21a2 2 0 0 0 3.464 0'}}, {'path': {'d': 'M13.916 2.314A6 6 0 0 0 6 8c0 4.499-1.411 5.956-2.74 7.327A1 1 0 0 0 4 17h16a1 1 0 0 0 .74-1.673 9 9 0 0 1-.585-.665'}}, {'circle': {'cx': '18', 'cy': '8', 'r': '3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def LifeBuoy(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-life-buoy'], 'items': [{'circle': {'cx': '12', 'cy': '12', 'r': '10'}}, {'path': {'d': 'm4.93 4.93 4.24 4.24'}}, {'path': {'d': 'm14.83 9.17 4.24-4.24'}}, {'path': {'d': 'm14.83 14.83 4.24 4.24'}}, {'path': {'d': 'm9.17 14.83-4.24 4.24'}}, {'circle': {'cx': '12', 'cy': '12', 'r': '4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PhoneMissed(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-phone-missed'], 'items': [{'path': {'d': 'm16 2 6 6'}}, {'path': {'d': 'm22 2-6 6'}}, {'path': {'d': 'M13.832 16.568a1 1 0 0 0 1.213-.303l.355-.465A2 2 0 0 1 17 15h3a2 2 0 0 1 2 2v3a2 2 0 0 1-2 2A18 18 0 0 1 2 4a2 2 0 0 1 2-2h3a2 2 0 0 1 2 2v3a2 2 0 0 1-.8 1.6l-.468.351a1 1 0 0 0-.292 1.233 14 14 0 0 0 6.392 6.384'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Accessibility(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-accessibility'], 'items': [{'circle': {'cx': '16', 'cy': '4', 'r': '1'}}, {'path': {'d': 'm18 19 1-7-6 1'}}, {'path': {'d': 'm5 8 3-3 5.5 3-2.36 3.5'}}, {'path': {'d': 'M4.24 14.5a5 5 0 0 0 6.88 6'}}, {'path': {'d': 'M13.76 17.5a5 5 0 0 0-6.88-6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ThermometerSun(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-thermometer-sun'], 'items': [{'path': {'d': 'M12 2v2'}}, {'path': {'d': 'M12 8a4 4 0 0 0-1.645 7.647'}}, {'path': {'d': 'M2 12h2'}}, {'path': {'d': 'M20 14.54a4 4 0 1 1-4 0V4a2 2 0 0 1 4 0z'}}, {'path': {'d': 'm4.93 4.93 1.41 1.41'}}, {'path': {'d': 'm6.34 17.66-1.41 1.41'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ShieldHalf(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-shield-half'], 'items': [{'path': {'d': 'M20 13c0 5-3.5 7.5-7.66 8.95a1 1 0 0 1-.67-.01C7.5 20.5 4 18 4 13V6a1 1 0 0 1 1-1c2 0 4.5-1.2 6.24-2.72a1.17 1.17 0 0 1 1.52 0C14.51 3.81 17 5 19 5a1 1 0 0 1 1 1z'}}, {'path': {'d': 'M12 22V2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Bean(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bean'], 'items': [{'path': {'d': 'M10.165 6.598C9.954 7.478 9.64 8.36 9 9c-.64.64-1.521.954-2.402 1.165A6 6 0 0 0 8 22c7.732 0 14-6.268 14-14a6 6 0 0 0-11.835-1.402Z'}}, {'path': {'d': 'M5.341 10.62a4 4 0 1 0 5.279-5.28'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Binary(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-binary'], 'items': [{'rect': {'x': '14', 'y': '14', 'width': '4', 'height': '6', 'rx': '2'}}, {'rect': {'x': '6', 'y': '4', 'width': '4', 'height': '6', 'rx': '2'}}, {'path': {'d': 'M6 20h4'}}, {'path': {'d': 'M14 10h4'}}, {'path': {'d': 'M6 14h2v6'}}, {'path': {'d': 'M14 4h2v6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Videotape(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-videotape'], 'items': [{'rect': {'width': '20', 'height': '16', 'x': '2', 'y': '4', 'rx': '2'}}, {'path': {'d': 'M2 8h20'}}, {'circle': {'cx': '8', 'cy': '14', 'r': '2'}}, {'path': {'d': 'M8 12h8'}}, {'circle': {'cx': '16', 'cy': '14', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Settings2(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-settings-2'], 'items': [{'path': {'d': 'M14 17H5'}}, {'path': {'d': 'M19 7h-9'}}, {'circle': {'cx': '17', 'cy': '17', 'r': '3'}}, {'circle': {'cx': '7', 'cy': '7', 'r': '3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ClipboardClock(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-clipboard-clock'], 'items': [{'path': {'d': 'M16 14v2.2l1.6 1'}}, {'path': {'d': 'M16 4h2a2 2 0 0 1 2 2v.832'}}, {'path': {'d': 'M8 4H6a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h2'}}, {'circle': {'cx': '16', 'cy': '16', 'r': '6'}}, {'rect': {'x': '8', 'y': '2', 'width': '8', 'height': '4', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Podcast(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-podcast'], 'items': [{'path': {'d': 'M13 17a1 1 0 1 0-2 0l.5 4.5a0.5 0.5 0 0 0 1 0z', 'fill': 'currentColor'}}, {'path': {'d': 'M16.85 18.58a9 9 0 1 0-9.7 0'}}, {'path': {'d': 'M8 14a5 5 0 1 1 8 0'}}, {'circle': {'cx': '12', 'cy': '11', 'r': '1', 'fill': 'currentColor'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BookmarkPlus(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bookmark-plus'], 'items': [{'path': {'d': 'm19 21-7-4-7 4V5a2 2 0 0 1 2-2h10a2 2 0 0 1 2 2v16z'}}, {'line': {'x1': '12', 'x2': '12', 'y1': '7', 'y2': '13'}}, {'line': {'x1': '15', 'x2': '9', 'y1': '10', 'y2': '10'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ArrowUpFromDot(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-arrow-up-from-dot'], 'items': [{'path': {'d': 'm5 9 7-7 7 7'}}, {'path': {'d': 'M12 16V2'}}, {'circle': {'cx': '12', 'cy': '21', 'r': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def GitPullRequestCreate(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-git-pull-request-create'], 'items': [{'circle': {'cx': '6', 'cy': '6', 'r': '3'}}, {'path': {'d': 'M6 9v12'}}, {'path': {'d': 'M13 6h3a2 2 0 0 1 2 2v3'}}, {'path': {'d': 'M18 15v6'}}, {'path': {'d': 'M21 18h-6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Pilcrow(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-pilcrow'], 'items': [{'path': {'d': 'M13 4v16'}}, {'path': {'d': 'M17 4v16'}}, {'path': {'d': 'M19 4H9.5a4.5 4.5 0 0 0 0 9H13'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MoveDown(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-move-down'], 'items': [{'path': {'d': 'M8 18L12 22L16 18'}}, {'path': {'d': 'M12 2V22'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def LocateOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-locate-off'], 'items': [{'path': {'d': 'M12 19v3'}}, {'path': {'d': 'M12 2v3'}}, {'path': {'d': 'M18.89 13.24a7 7 0 0 0-8.13-8.13'}}, {'path': {'d': 'M19 12h3'}}, {'path': {'d': 'M2 12h3'}}, {'path': {'d': 'm2 2 20 20'}}, {'path': {'d': 'M7.05 7.05a7 7 0 0 0 9.9 9.9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquaresSubtract(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-squares-subtract'], 'items': [{'path': {'d': 'M10 22a2 2 0 0 1-2-2'}}, {'path': {'d': 'M16 22h-2'}}, {'path': {'d': 'M16 4a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h3a1 1 0 0 0 1-1v-5a2 2 0 0 1 2-2h5a1 1 0 0 0 1-1z'}}, {'path': {'d': 'M20 8a2 2 0 0 1 2 2'}}, {'path': {'d': 'M22 14v2'}}, {'path': {'d': 'M22 20a2 2 0 0 1-2 2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def RemoveFormatting(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-remove-formatting'], 'items': [{'path': {'d': 'M4 7V4h16v3'}}, {'path': {'d': 'M5 20h6'}}, {'path': {'d': 'M13 4 8 20'}}, {'path': {'d': 'm15 15 5 5'}}, {'path': {'d': 'm20 15-5 5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquareActivity(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-activity'], 'items': [{'rect': {'width': '18', 'height': '18', 'x': '3', 'y': '3', 'rx': '2'}}, {'path': {'d': 'M17 12h-2l-2 5-2-10-2 5H7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Cloudy(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-cloudy'], 'items': [{'path': {'d': 'M17.5 21H9a7 7 0 1 1 6.71-9h1.79a4.5 4.5 0 1 1 0 9Z'}}, {'path': {'d': 'M22 10a3 3 0 0 0-3-3h-2.207a5.502 5.502 0 0 0-10.702.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ListCheck(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-list-check'], 'items': [{'path': {'d': 'M16 5H3'}}, {'path': {'d': 'M16 12H3'}}, {'path': {'d': 'M11 19H3'}}, {'path': {'d': 'm15 18 2 2 4-4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Bed(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bed'], 'items': [{'path': {'d': 'M2 4v16'}}, {'path': {'d': 'M2 8h18a2 2 0 0 1 2 2v10'}}, {'path': {'d': 'M2 17h20'}}, {'path': {'d': 'M6 8v9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Headphones(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-headphones'], 'items': [{'path': {'d': 'M3 14h3a2 2 0 0 1 2 2v3a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-7a9 9 0 0 1 18 0v7a2 2 0 0 1-2 2h-1a2 2 0 0 1-2-2v-3a2 2 0 0 1 2-2h3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Popsicle(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-popsicle'], 'items': [{'path': {'d': 'M18.6 14.4c.8-.8.8-2 0-2.8l-8.1-8.1a4.95 4.95 0 1 0-7.1 7.1l8.1 8.1c.9.7 2.1.7 2.9-.1Z'}}, {'path': {'d': 'm22 22-5.5-5.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BotMessageSquare(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bot-message-square'], 'items': [{'path': {'d': 'M12 6V2H8'}}, {'path': {'d': 'M15 11v2'}}, {'path': {'d': 'M2 12h2'}}, {'path': {'d': 'M20 12h2'}}, {'path': {'d': 'M20 16a2 2 0 0 1-2 2H8.828a2 2 0 0 0-1.414.586l-2.202 2.202A.71.71 0 0 1 4 20.286V8a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2z'}}, {'path': {'d': 'M9 11v2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Spade(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-spade'], 'items': [{'path': {'d': 'M12 18v4'}}, {'path': {'d': 'M2 14.499a5.5 5.5 0 0 0 9.591 3.675.6.6 0 0 1 .818.001A5.5 5.5 0 0 0 22 14.5c0-2.29-1.5-4-3-5.5l-5.492-5.312a2 2 0 0 0-3-.02L5 8.999c-1.5 1.5-3 3.2-3 5.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ChartColumnStacked(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-chart-column-stacked'], 'items': [{'path': {'d': 'M11 13H7'}}, {'path': {'d': 'M19 9h-4'}}, {'path': {'d': 'M3 3v16a2 2 0 0 0 2 2h16'}}, {'rect': {'x': '15', 'y': '5', 'width': '4', 'height': '12', 'rx': '1'}}, {'rect': {'x': '7', 'y': '8', 'width': '4', 'height': '9', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ArrowLeftRight(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-arrow-left-right'], 'items': [{'path': {'d': 'M8 3 4 7l4 4'}}, {'path': {'d': 'M4 7h16'}}, {'path': {'d': 'm16 21 4-4-4-4'}}, {'path': {'d': 'M20 17H4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquareStack(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-stack'], 'items': [{'path': {'d': 'M4 10c-1.1 0-2-.9-2-2V4c0-1.1.9-2 2-2h4c1.1 0 2 .9 2 2'}}, {'path': {'d': 'M10 16c-1.1 0-2-.9-2-2v-4c0-1.1.9-2 2-2h4c1.1 0 2 .9 2 2'}}, {'rect': {'width': '8', 'height': '8', 'x': '14', 'y': '14', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Info(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-info'], 'items': [{'circle': {'cx': '12', 'cy': '12', 'r': '10'}}, {'path': {'d': 'M12 16v-4'}}, {'path': {'d': 'M12 8h.01'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Hotel(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-hotel'], 'items': [{'path': {'d': 'M10 22v-6.57'}}, {'path': {'d': 'M12 11h.01'}}, {'path': {'d': 'M12 7h.01'}}, {'path': {'d': 'M14 15.43V22'}}, {'path': {'d': 'M15 16a5 5 0 0 0-6 0'}}, {'path': {'d': 'M16 11h.01'}}, {'path': {'d': 'M16 7h.01'}}, {'path': {'d': 'M8 11h.01'}}, {'path': {'d': 'M8 7h.01'}}, {'rect': {'x': '4', 'y': '2', 'width': '16', 'height': '20', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ShoppingCart(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-shopping-cart'], 'items': [{'circle': {'cx': '8', 'cy': '21', 'r': '1'}}, {'circle': {'cx': '19', 'cy': '21', 'r': '1'}}, {'path': {'d': 'M2.05 2.05h2l2.66 12.42a2 2 0 0 0 2 1.58h9.78a2 2 0 0 0 1.95-1.57l1.65-7.43H5.12'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquareDashedBottomCode(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-dashed-bottom-code'], 'items': [{'path': {'d': 'M10 9.5 8 12l2 2.5'}}, {'path': {'d': 'M14 21h1'}}, {'path': {'d': 'm14 9.5 2 2.5-2 2.5'}}, {'path': {'d': 'M5 21a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2'}}, {'path': {'d': 'M9 21h1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ReplyAll(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-reply-all'], 'items': [{'path': {'d': 'm12 17-5-5 5-5'}}, {'path': {'d': 'M22 18v-2a4 4 0 0 0-4-4H7'}}, {'path': {'d': 'm7 17-5-5 5-5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Scissors(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-scissors'], 'items': [{'circle': {'cx': '6', 'cy': '6', 'r': '3'}}, {'path': {'d': 'M8.12 8.12 12 12'}}, {'path': {'d': 'M20 4 8.12 15.88'}}, {'circle': {'cx': '6', 'cy': '18', 'r': '3'}}, {'path': {'d': 'M14.8 14.8 20 20'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Birdhouse(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-birdhouse'], 'items': [{'path': {'d': 'M12 18v4'}}, {'path': {'d': 'm17 18 1.956-11.468'}}, {'path': {'d': 'm3 8 7.82-5.615a2 2 0 0 1 2.36 0L21 8'}}, {'path': {'d': 'M4 18h16'}}, {'path': {'d': 'M7 18 5.044 6.532'}}, {'circle': {'cx': '12', 'cy': '10', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Compass(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-compass'], 'items': [{'path': {'d': 'm16.24 7.76-1.804 5.411a2 2 0 0 1-1.265 1.265L7.76 16.24l1.804-5.411a2 2 0 0 1 1.265-1.265z'}}, {'circle': {'cx': '12', 'cy': '12', 'r': '10'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Type(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-type'], 'items': [{'path': {'d': 'M12 4v16'}}, {'path': {'d': 'M4 7V5a1 1 0 0 1 1-1h14a1 1 0 0 1 1 1v2'}}, {'path': {'d': 'M9 20h6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CupSoda(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-cup-soda'], 'items': [{'path': {'d': 'm6 8 1.75 12.28a2 2 0 0 0 2 1.72h4.54a2 2 0 0 0 2-1.72L18 8'}}, {'path': {'d': 'M5 8h14'}}, {'path': {'d': 'M7 15a6.47 6.47 0 0 1 5 0 6.47 6.47 0 0 0 5 0'}}, {'path': {'d': 'm12 8 1-6h2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def EggFried(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-egg-fried'], 'items': [{'circle': {'cx': '11.5', 'cy': '12.5', 'r': '3.5'}}, {'path': {'d': 'M3 8c0-3.5 2.5-6 6.5-6 5 0 4.83 3 7.5 5s5 2 5 6c0 4.5-2.5 6.5-7 6.5-2.5 0-2.5 2.5-6 2.5s-7-2-7-5.5c0-3 1.5-3 1.5-5C3.5 10 3 9 3 8Z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Rainbow(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-rainbow'], 'items': [{'path': {'d': 'M22 17a10 10 0 0 0-20 0'}}, {'path': {'d': 'M6 17a6 6 0 0 1 12 0'}}, {'path': {'d': 'M10 17a2 2 0 0 1 4 0'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def GitPullRequestClosed(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-git-pull-request-closed'], 'items': [{'circle': {'cx': '6', 'cy': '6', 'r': '3'}}, {'path': {'d': 'M6 9v12'}}, {'path': {'d': 'm21 3-6 6'}}, {'path': {'d': 'm21 9-6-6'}}, {'path': {'d': 'M18 11.5V15'}}, {'circle': {'cx': '18', 'cy': '18', 'r': '3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BookUp2(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-book-up-2'], 'items': [{'path': {'d': 'M12 13V7'}}, {'path': {'d': 'M18 2h1a1 1 0 0 1 1 1v18a1 1 0 0 1-1 1H6.5a1 1 0 0 1 0-5H20'}}, {'path': {'d': 'M4 19.5v-15A2.5 2.5 0 0 1 6.5 2'}}, {'path': {'d': 'm9 10 3-3 3 3'}}, {'path': {'d': 'm9 5 3-3 3 3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CloudDrizzle(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-cloud-drizzle'], 'items': [{'path': {'d': 'M4 14.899A7 7 0 1 1 15.71 8h1.79a4.5 4.5 0 0 1 2.5 8.242'}}, {'path': {'d': 'M8 19v1'}}, {'path': {'d': 'M8 14v1'}}, {'path': {'d': 'M16 19v1'}}, {'path': {'d': 'M16 14v1'}}, {'path': {'d': 'M12 21v1'}}, {'path': {'d': 'M12 16v1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def HatGlasses(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-hat-glasses'], 'items': [{'path': {'d': 'M14 18a2 2 0 0 0-4 0'}}, {'path': {'d': 'm19 11-2.11-6.657a2 2 0 0 0-2.752-1.148l-1.276.61A2 2 0 0 1 12 4H8.5a2 2 0 0 0-1.925 1.456L5 11'}}, {'path': {'d': 'M2 11h20'}}, {'circle': {'cx': '17', 'cy': '18', 'r': '3'}}, {'circle': {'cx': '7', 'cy': '18', 'r': '3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Skull(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-skull'], 'items': [{'path': {'d': 'm12.5 17-.5-1-.5 1h1z'}}, {'path': {'d': 'M15 22a1 1 0 0 0 1-1v-1a2 2 0 0 0 1.56-3.25 8 8 0 1 0-11.12 0A2 2 0 0 0 8 20v1a1 1 0 0 0 1 1z'}}, {'circle': {'cx': '15', 'cy': '12', 'r': '1'}}, {'circle': {'cx': '9', 'cy': '12', 'r': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Music3(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-music-3'], 'items': [{'circle': {'cx': '12', 'cy': '18', 'r': '4'}}, {'path': {'d': 'M16 18V2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def DollarSign(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-dollar-sign'], 'items': [{'line': {'x1': '12', 'x2': '12', 'y1': '2', 'y2': '22'}}, {'path': {'d': 'M17 5H9.5a3.5 3.5 0 0 0 0 7h5a3.5 3.5 0 0 1 0 7H6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Minimize(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-minimize'], 'items': [{'path': {'d': 'M8 3v3a2 2 0 0 1-2 2H3'}}, {'path': {'d': 'M21 8h-3a2 2 0 0 1-2-2V3'}}, {'path': {'d': 'M3 16h3a2 2 0 0 1 2 2v3'}}, {'path': {'d': 'M16 21v-3a2 2 0 0 1 2-2h3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Italic(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-italic'], 'items': [{'line': {'x1': '19', 'x2': '10', 'y1': '4', 'y2': '4'}}, {'line': {'x1': '14', 'x2': '5', 'y1': '20', 'y2': '20'}}, {'line': {'x1': '15', 'x2': '9', 'y1': '4', 'y2': '20'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Mars(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-mars'], 'items': [{'path': {'d': 'M16 3h5v5'}}, {'path': {'d': 'm21 3-6.75 6.75'}}, {'circle': {'cx': '10', 'cy': '14', 'r': '6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BrushCleaning(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-brush-cleaning'], 'items': [{'path': {'d': 'm16 22-1-4'}}, {'path': {'d': 'M19 13.99a1 1 0 0 0 1-1V12a2 2 0 0 0-2-2h-3a1 1 0 0 1-1-1V4a2 2 0 0 0-4 0v5a1 1 0 0 1-1 1H6a2 2 0 0 0-2 2v.99a1 1 0 0 0 1 1'}}, {'path': {'d': 'M5 14h14l1.973 6.767A1 1 0 0 1 20 22H4a1 1 0 0 1-.973-1.233z'}}, {'path': {'d': 'm8 22 1-4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MoveUpRight(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-move-up-right'], 'items': [{'path': {'d': 'M13 5H19V11'}}, {'path': {'d': 'M19 5L5 19'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Wind(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-wind'], 'items': [{'path': {'d': 'M12.8 19.6A2 2 0 1 0 14 16H2'}}, {'path': {'d': 'M17.5 8a2.5 2.5 0 1 1 2 4H2'}}, {'path': {'d': 'M9.8 4.4A2 2 0 1 1 11 8H2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CaptionsOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-captions-off'], 'items': [{'path': {'d': 'M10.5 5H19a2 2 0 0 1 2 2v8.5'}}, {'path': {'d': 'M17 11h-.5'}}, {'path': {'d': 'M19 19H5a2 2 0 0 1-2-2V7a2 2 0 0 1 2-2'}}, {'path': {'d': 'm2 2 20 20'}}, {'path': {'d': 'M7 11h4'}}, {'path': {'d': 'M7 15h2.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FolderSymlink(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-folder-symlink'], 'items': [{'path': {'d': 'M2 9.35V5a2 2 0 0 1 2-2h3.9a2 2 0 0 1 1.69.9l.81 1.2a2 2 0 0 0 1.67.9H20a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2v-3a2 2 0 0 1 2-2h7'}}, {'path': {'d': 'm8 16 3-3-3-3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def UnfoldVertical(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-unfold-vertical'], 'items': [{'path': {'d': 'M12 22v-6'}}, {'path': {'d': 'M12 8V2'}}, {'path': {'d': 'M4 12H2'}}, {'path': {'d': 'M10 12H8'}}, {'path': {'d': 'M16 12h-2'}}, {'path': {'d': 'M22 12h-2'}}, {'path': {'d': 'm15 19-3 3-3-3'}}, {'path': {'d': 'm15 5-3-3-3 3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MapPinMinus(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-map-pin-minus'], 'items': [{'path': {'d': 'M18.977 14C19.6 12.701 20 11.343 20 10a8 8 0 0 0-16 0c0 4.993 5.539 10.193 7.399 11.799a1 1 0 0 0 1.202 0 32 32 0 0 0 .824-.738'}}, {'circle': {'cx': '12', 'cy': '10', 'r': '3'}}, {'path': {'d': 'M16 18h6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ChartColumn(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-chart-column'], 'items': [{'path': {'d': 'M3 3v16a2 2 0 0 0 2 2h16'}}, {'path': {'d': 'M18 17V9'}}, {'path': {'d': 'M13 17V5'}}, {'path': {'d': 'M8 17v-3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Album(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-album'], 'items': [{'rect': {'width': '18', 'height': '18', 'x': '3', 'y': '3', 'rx': '2', 'ry': '2'}}, {'polyline': {'points': '11 3 11 11 14 8 17 11 17 3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Toilet(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-toilet'], 'items': [{'path': {'d': 'M7 12h13a1 1 0 0 1 1 1 5 5 0 0 1-5 5h-.598a.5.5 0 0 0-.424.765l1.544 2.47a.5.5 0 0 1-.424.765H5.402a.5.5 0 0 1-.424-.765L7 18'}}, {'path': {'d': 'M8 18a5 5 0 0 1-5-5V4a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TextAlignStart(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-text-align-start'], 'items': [{'path': {'d': 'M21 5H3'}}, {'path': {'d': 'M15 12H3'}}, {'path': {'d': 'M17 19H3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Power(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-power'], 'items': [{'path': {'d': 'M12 2v10'}}, {'path': {'d': 'M18.4 6.6a9 9 0 1 1-12.77.04'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Dices(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-dices'], 'items': [{'rect': {'width': '12', 'height': '12', 'x': '2', 'y': '10', 'rx': '2', 'ry': '2'}}, {'path': {'d': 'm17.92 14 3.5-3.5a2.24 2.24 0 0 0 0-3l-5-4.92a2.24 2.24 0 0 0-3 0L10 6'}}, {'path': {'d': 'M6 18h.01'}}, {'path': {'d': 'M10 14h.01'}}, {'path': {'d': 'M15 6h.01'}}, {'path': {'d': 'M18 9h.01'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def GitCompareArrows(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-git-compare-arrows'], 'items': [{'circle': {'cx': '5', 'cy': '6', 'r': '3'}}, {'path': {'d': 'M12 6h5a2 2 0 0 1 2 2v7'}}, {'path': {'d': 'm15 9-3-3 3-3'}}, {'circle': {'cx': '19', 'cy': '18', 'r': '3'}}, {'path': {'d': 'M12 18H7a2 2 0 0 1-2-2V9'}}, {'path': {'d': 'm9 15 3 3-3 3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Maximize(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-maximize'], 'items': [{'path': {'d': 'M8 3H5a2 2 0 0 0-2 2v3'}}, {'path': {'d': 'M21 8V5a2 2 0 0 0-2-2h-3'}}, {'path': {'d': 'M3 16v3a2 2 0 0 0 2 2h3'}}, {'path': {'d': 'M16 21h3a2 2 0 0 0 2-2v-3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FileClock(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-file-clock'], 'items': [{'path': {'d': 'M16 22h2a2 2 0 0 0 2-2V8a2.4 2.4 0 0 0-.706-1.706l-3.588-3.588A2.4 2.4 0 0 0 14 2H6a2 2 0 0 0-2 2v2.85'}}, {'path': {'d': 'M14 2v5a1 1 0 0 0 1 1h5'}}, {'path': {'d': 'M8 14v2.2l1.6 1'}}, {'circle': {'cx': '8', 'cy': '16', 'r': '6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def WholeWord(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-whole-word'], 'items': [{'circle': {'cx': '7', 'cy': '12', 'r': '3'}}, {'path': {'d': 'M10 9v6'}}, {'circle': {'cx': '17', 'cy': '12', 'r': '3'}}, {'path': {'d': 'M14 7v8'}}, {'path': {'d': 'M22 17v1c0 .5-.5 1-1 1H3c-.5 0-1-.5-1-1v-1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Infinity(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-infinity'], 'items': [{'path': {'d': 'M6 16c5 0 7-8 12-8a4 4 0 0 1 0 8c-5 0-7-8-12-8a4 4 0 1 0 0 8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MessageSquareText(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-message-square-text'], 'items': [{'path': {'d': 'M22 17a2 2 0 0 1-2 2H6.828a2 2 0 0 0-1.414.586l-2.202 2.202A.71.71 0 0 1 2 21.286V5a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2z'}}, {'path': {'d': 'M7 11h10'}}, {'path': {'d': 'M7 15h6'}}, {'path': {'d': 'M7 7h8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def IterationCw(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-iteration-cw'], 'items': [{'path': {'d': 'M4 10a8 8 0 1 1 8 8H4'}}, {'path': {'d': 'm8 22-4-4 4-4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ListMinus(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-list-minus'], 'items': [{'path': {'d': 'M16 5H3'}}, {'path': {'d': 'M11 12H3'}}, {'path': {'d': 'M16 19H3'}}, {'path': {'d': 'M21 12h-6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CloudRainWind(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-cloud-rain-wind'], 'items': [{'path': {'d': 'M4 14.899A7 7 0 1 1 15.71 8h1.79a4.5 4.5 0 0 1 2.5 8.242'}}, {'path': {'d': 'm9.2 22 3-7'}}, {'path': {'d': 'm9 13-3 7'}}, {'path': {'d': 'm17 13-3 7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Repeat2(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-repeat-2'], 'items': [{'path': {'d': 'm2 9 3-3 3 3'}}, {'path': {'d': 'M13 18H7a2 2 0 0 1-2-2V6'}}, {'path': {'d': 'm22 15-3 3-3-3'}}, {'path': {'d': 'M11 6h6a2 2 0 0 1 2 2v10'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Joystick(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-joystick'], 'items': [{'path': {'d': 'M21 17a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v2a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2v-2Z'}}, {'path': {'d': 'M6 15v-2'}}, {'path': {'d': 'M12 15V9'}}, {'circle': {'cx': '12', 'cy': '6', 'r': '3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ImagePlay(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-image-play'], 'items': [{'path': {'d': 'M15 15.003a1 1 0 0 1 1.517-.859l4.997 2.997a1 1 0 0 1 0 1.718l-4.997 2.997a1 1 0 0 1-1.517-.86z'}}, {'path': {'d': 'M21 12.17V5a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h6'}}, {'path': {'d': 'm6 21 5-5'}}, {'circle': {'cx': '9', 'cy': '9', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FlameKindling(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-flame-kindling'], 'items': [{'path': {'d': 'M12 2c1 3 2.5 3.5 3.5 4.5A5 5 0 0 1 17 10a5 5 0 1 1-10 0c0-.3 0-.6.1-.9a2 2 0 1 0 3.3-2C8 4.5 11 2 12 2Z'}}, {'path': {'d': 'm5 22 14-4'}}, {'path': {'d': 'm5 18 14 4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Search(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-search'], 'items': [{'path': {'d': 'm21 21-4.34-4.34'}}, {'circle': {'cx': '11', 'cy': '11', 'r': '8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ArrowUpLeft(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-arrow-up-left'], 'items': [{'path': {'d': 'M7 17V7h10'}}, {'path': {'d': 'M17 17 7 7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Sailboat(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-sailboat'], 'items': [{'path': {'d': 'M10 2v15'}}, {'path': {'d': 'M7 22a4 4 0 0 1-4-4 1 1 0 0 1 1-1h16a1 1 0 0 1 1 1 4 4 0 0 1-4 4z'}}, {'path': {'d': 'M9.159 2.46a1 1 0 0 1 1.521-.193l9.977 8.98A1 1 0 0 1 20 13H4a1 1 0 0 1-.824-1.567z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BookKey(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-book-key'], 'items': [{'path': {'d': 'm19 3 1 1'}}, {'path': {'d': 'm20 2-4.5 4.5'}}, {'path': {'d': 'M20 7.898V21a1 1 0 0 1-1 1H6.5a1 1 0 0 1 0-5H20'}}, {'path': {'d': 'M4 19.5v-15A2.5 2.5 0 0 1 6.5 2h7.844'}}, {'circle': {'cx': '14', 'cy': '8', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def NotepadText(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-notepad-text'], 'items': [{'path': {'d': 'M8 2v4'}}, {'path': {'d': 'M12 2v4'}}, {'path': {'d': 'M16 2v4'}}, {'rect': {'width': '16', 'height': '18', 'x': '4', 'y': '4', 'rx': '2'}}, {'path': {'d': 'M8 10h6'}}, {'path': {'d': 'M8 14h8'}}, {'path': {'d': 'M8 18h5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def KeyRound(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-key-round'], 'items': [{'path': {'d': 'M2.586 17.414A2 2 0 0 0 2 18.828V21a1 1 0 0 0 1 1h3a1 1 0 0 0 1-1v-1a1 1 0 0 1 1-1h1a1 1 0 0 0 1-1v-1a1 1 0 0 1 1-1h.172a2 2 0 0 0 1.414-.586l.814-.814a6.5 6.5 0 1 0-4-4z'}}, {'circle': {'cx': '16.5', 'cy': '7.5', 'r': '.5', 'fill': 'currentColor'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Tag(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-tag'], 'items': [{'path': {'d': 'M12.586 2.586A2 2 0 0 0 11.172 2H4a2 2 0 0 0-2 2v7.172a2 2 0 0 0 .586 1.414l8.704 8.704a2.426 2.426 0 0 0 3.42 0l6.58-6.58a2.426 2.426 0 0 0 0-3.42z'}}, {'circle': {'cx': '7.5', 'cy': '7.5', 'r': '.5', 'fill': 'currentColor'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SpellCheck(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-spell-check'], 'items': [{'path': {'d': 'm6 16 6-12 6 12'}}, {'path': {'d': 'M8 12h8'}}, {'path': {'d': 'm16 20 2 2 4-4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MoveRight(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-move-right'], 'items': [{'path': {'d': 'M18 8L22 12L18 16'}}, {'path': {'d': 'M2 12H22'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ThermometerSnowflake(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-thermometer-snowflake'], 'items': [{'path': {'d': 'm10 20-1.25-2.5L6 18'}}, {'path': {'d': 'M10 4 8.75 6.5 6 6'}}, {'path': {'d': 'M10.585 15H10'}}, {'path': {'d': 'M2 12h6.5L10 9'}}, {'path': {'d': 'M20 14.54a4 4 0 1 1-4 0V4a2 2 0 0 1 4 0z'}}, {'path': {'d': 'm4 10 1.5 2L4 14'}}, {'path': {'d': 'm7 21 3-6-1.5-3'}}, {'path': {'d': 'm7 3 3 6h2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Sticker(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-sticker'], 'items': [{'path': {'d': 'M21 9a2.4 2.4 0 0 0-.706-1.706l-3.588-3.588A2.4 2.4 0 0 0 15 3H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2z'}}, {'path': {'d': 'M15 3v5a1 1 0 0 0 1 1h5'}}, {'path': {'d': 'M8 13h.01'}}, {'path': {'d': 'M16 13h.01'}}, {'path': {'d': 'M10 16s.8 1 2 1c1.3 0 2-1 2-1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Hexagon(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-hexagon'], 'items': [{'path': {'d': 'M21 16V8a2 2 0 0 0-1-1.73l-7-4a2 2 0 0 0-2 0l-7 4A2 2 0 0 0 3 8v8a2 2 0 0 0 1 1.73l7 4a2 2 0 0 0 2 0l7-4A2 2 0 0 0 21 16z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def WifiLow(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-wifi-low'], 'items': [{'path': {'d': 'M12 20h.01'}}, {'path': {'d': 'M8.5 16.429a5 5 0 0 1 7 0'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TextWrap(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-text-wrap'], 'items': [{'path': {'d': 'm16 16-3 3 3 3'}}, {'path': {'d': 'M3 12h14.5a1 1 0 0 1 0 7H13'}}, {'path': {'d': 'M3 19h6'}}, {'path': {'d': 'M3 5h18'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Volume(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-volume'], 'items': [{'path': {'d': 'M11 4.702a.705.705 0 0 0-1.203-.498L6.413 7.587A1.4 1.4 0 0 1 5.416 8H3a1 1 0 0 0-1 1v6a1 1 0 0 0 1 1h2.416a1.4 1.4 0 0 1 .997.413l3.383 3.384A.705.705 0 0 0 11 19.298z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MicOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-mic-off'], 'items': [{'path': {'d': 'M12 19v3'}}, {'path': {'d': 'M15 9.34V5a3 3 0 0 0-5.68-1.33'}}, {'path': {'d': 'M16.95 16.95A7 7 0 0 1 5 12v-2'}}, {'path': {'d': 'M18.89 13.23A7 7 0 0 0 19 12v-2'}}, {'path': {'d': 'm2 2 20 20'}}, {'path': {'d': 'M9 9v3a3 3 0 0 0 5.12 2.12'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Zap(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-zap'], 'items': [{'path': {'d': 'M4 14a1 1 0 0 1-.78-1.63l9.9-10.2a.5.5 0 0 1 .86.46l-1.92 6.02A1 1 0 0 0 13 10h7a1 1 0 0 1 .78 1.63l-9.9 10.2a.5.5 0 0 1-.86-.46l1.92-6.02A1 1 0 0 0 11 14z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CalendarOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-calendar-off'], 'items': [{'path': {'d': 'M4.2 4.2A2 2 0 0 0 3 6v14a2 2 0 0 0 2 2h14a2 2 0 0 0 1.82-1.18'}}, {'path': {'d': 'M21 15.5V6a2 2 0 0 0-2-2H9.5'}}, {'path': {'d': 'M16 2v4'}}, {'path': {'d': 'M3 10h7'}}, {'path': {'d': 'M21 10h-5.5'}}, {'path': {'d': 'm2 2 20 20'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Logs(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-logs'], 'items': [{'path': {'d': 'M3 5h1'}}, {'path': {'d': 'M3 12h1'}}, {'path': {'d': 'M3 19h1'}}, {'path': {'d': 'M8 5h1'}}, {'path': {'d': 'M8 12h1'}}, {'path': {'d': 'M8 19h1'}}, {'path': {'d': 'M13 5h8'}}, {'path': {'d': 'M13 12h8'}}, {'path': {'d': 'M13 19h8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CalendarHeart(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-calendar-heart'], 'items': [{'path': {'d': 'M12.127 22H5a2 2 0 0 1-2-2V6a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2v5.125'}}, {'path': {'d': 'M14.62 18.8A2.25 2.25 0 1 1 18 15.836a2.25 2.25 0 1 1 3.38 2.966l-2.626 2.856a.998.998 0 0 1-1.507 0z'}}, {'path': {'d': 'M16 2v4'}}, {'path': {'d': 'M3 10h18'}}, {'path': {'d': 'M8 2v4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Webcam(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-webcam'], 'items': [{'circle': {'cx': '12', 'cy': '10', 'r': '8'}}, {'circle': {'cx': '12', 'cy': '10', 'r': '3'}}, {'path': {'d': 'M7 22h10'}}, {'path': {'d': 'M12 22v-4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Merge(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-merge'], 'items': [{'path': {'d': 'm8 6 4-4 4 4'}}, {'path': {'d': 'M12 2v10.3a4 4 0 0 1-1.172 2.872L4 22'}}, {'path': {'d': 'm20 22-5-5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def AtSign(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-at-sign'], 'items': [{'circle': {'cx': '12', 'cy': '12', 'r': '4'}}, {'path': {'d': 'M16 8v5a3 3 0 0 0 6 0v-1a10 10 0 1 0-4 8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BatteryPlus(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-battery-plus'], 'items': [{'path': {'d': 'M10 9v6'}}, {'path': {'d': 'M12.543 6H16a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2h-3.605'}}, {'path': {'d': 'M22 14v-4'}}, {'path': {'d': 'M7 12h6'}}, {'path': {'d': 'M7.606 18H4a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h3.606'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TimerReset(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-timer-reset'], 'items': [{'path': {'d': 'M10 2h4'}}, {'path': {'d': 'M12 14v-4'}}, {'path': {'d': 'M4 13a8 8 0 0 1 8-7 8 8 0 1 1-5.3 14L4 17.6'}}, {'path': {'d': 'M9 17H4v5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ReceiptSwissFranc(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-receipt-swiss-franc'], 'items': [{'path': {'d': 'M4 2v20l2-1 2 1 2-1 2 1 2-1 2 1 2-1 2 1V2l-2 1-2-1-2 1-2-1-2 1-2-1-2 1Z'}}, {'path': {'d': 'M10 17V7h5'}}, {'path': {'d': 'M10 11h4'}}, {'path': {'d': 'M8 15h5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def GitMerge(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-git-merge'], 'items': [{'circle': {'cx': '18', 'cy': '18', 'r': '3'}}, {'circle': {'cx': '6', 'cy': '6', 'r': '3'}}, {'path': {'d': 'M6 21V9a9 9 0 0 0 9 9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def DecimalsArrowRight(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-decimals-arrow-right'], 'items': [{'path': {'d': 'M10 18h10'}}, {'path': {'d': 'm17 21 3-3-3-3'}}, {'path': {'d': 'M3 11h.01'}}, {'rect': {'x': '15', 'y': '3', 'width': '5', 'height': '8', 'rx': '2.5'}}, {'rect': {'x': '6', 'y': '3', 'width': '5', 'height': '8', 'rx': '2.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MemoryStick(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-memory-stick'], 'items': [{'path': {'d': 'M6 19v-3'}}, {'path': {'d': 'M10 19v-3'}}, {'path': {'d': 'M14 19v-3'}}, {'path': {'d': 'M18 19v-3'}}, {'path': {'d': 'M8 11V9'}}, {'path': {'d': 'M16 11V9'}}, {'path': {'d': 'M12 11V9'}}, {'path': {'d': 'M2 15h20'}}, {'path': {'d': 'M2 7a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v1.1a2 2 0 0 0 0 3.837V17a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2v-5.1a2 2 0 0 0 0-3.837Z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CandyCane(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-candy-cane'], 'items': [{'path': {'d': 'M5.7 21a2 2 0 0 1-3.5-2l8.6-14a6 6 0 0 1 10.4 6 2 2 0 1 1-3.464-2 2 2 0 1 0-3.464-2Z'}}, {'path': {'d': 'M17.75 7 15 2.1'}}, {'path': {'d': 'M10.9 4.8 13 9'}}, {'path': {'d': 'm7.9 9.7 2 4.4'}}, {'path': {'d': 'M4.9 14.7 7 18.9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FlipHorizontal(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-flip-horizontal'], 'items': [{'path': {'d': 'M8 3H5a2 2 0 0 0-2 2v14c0 1.1.9 2 2 2h3'}}, {'path': {'d': 'M16 3h3a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2h-3'}}, {'path': {'d': 'M12 20v2'}}, {'path': {'d': 'M12 14v2'}}, {'path': {'d': 'M12 8v2'}}, {'path': {'d': 'M12 2v2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CirclePoundSterling(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-circle-pound-sterling'], 'items': [{'path': {'d': 'M10 16V9.5a1 1 0 0 1 5 0'}}, {'path': {'d': 'M8 12h4'}}, {'path': {'d': 'M8 16h7'}}, {'circle': {'cx': '12', 'cy': '12', 'r': '10'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Thermometer(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-thermometer'], 'items': [{'path': {'d': 'M14 4v10.54a4 4 0 1 1-4 0V4a2 2 0 0 1 4 0Z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FolderOpen(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-folder-open'], 'items': [{'path': {'d': 'm6 14 1.5-2.9A2 2 0 0 1 9.24 10H20a2 2 0 0 1 1.94 2.5l-1.54 6a2 2 0 0 1-1.95 1.5H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h3.9a2 2 0 0 1 1.69.9l.81 1.2a2 2 0 0 0 1.67.9H18a2 2 0 0 1 2 2v2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BriefcaseConveyorBelt(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-briefcase-conveyor-belt'], 'items': [{'path': {'d': 'M10 20v2'}}, {'path': {'d': 'M14 20v2'}}, {'path': {'d': 'M18 20v2'}}, {'path': {'d': 'M21 20H3'}}, {'path': {'d': 'M6 20v2'}}, {'path': {'d': 'M8 16V4a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2v12'}}, {'rect': {'x': '4', 'y': '6', 'width': '16', 'height': '10', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Mailbox(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-mailbox'], 'items': [{'path': {'d': 'M22 17a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V9.5C2 7 4 5 6.5 5H18c2.2 0 4 1.8 4 4v8Z'}}, {'polyline': {'points': '15,9 18,9 18,11'}}, {'path': {'d': 'M6.5 5C9 5 11 7 11 9.5V17a2 2 0 0 1-2 2'}}, {'line': {'x1': '6', 'x2': '7', 'y1': '10', 'y2': '10'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def LineSquiggle(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-line-squiggle'], 'items': [{'path': {'d': 'M7 3.5c5-2 7 2.5 3 4C1.5 10 2 15 5 16c5 2 9-10 14-7s.5 13.5-4 12c-5-2.5.5-11 6-2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CalendarSync(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-calendar-sync'], 'items': [{'path': {'d': 'M11 10v4h4'}}, {'path': {'d': 'm11 14 1.535-1.605a5 5 0 0 1 8 1.5'}}, {'path': {'d': 'M16 2v4'}}, {'path': {'d': 'm21 18-1.535 1.605a5 5 0 0 1-8-1.5'}}, {'path': {'d': 'M21 22v-4h-4'}}, {'path': {'d': 'M21 8.5V6a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h4.3'}}, {'path': {'d': 'M3 10h4'}}, {'path': {'d': 'M8 2v4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def GitBranch(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-git-branch'], 'items': [{'line': {'x1': '6', 'x2': '6', 'y1': '3', 'y2': '15'}}, {'circle': {'cx': '18', 'cy': '6', 'r': '3'}}, {'circle': {'cx': '6', 'cy': '18', 'r': '3'}}, {'path': {'d': 'M18 9a9 9 0 0 1-9 9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Scale3d(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-scale-3d'], 'items': [{'path': {'d': 'M5 7v11a1 1 0 0 0 1 1h11'}}, {'path': {'d': 'M5.293 18.707 11 13'}}, {'circle': {'cx': '19', 'cy': '19', 'r': '2'}}, {'circle': {'cx': '5', 'cy': '5', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ImageUpscale(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-image-upscale'], 'items': [{'path': {'d': 'M16 3h5v5'}}, {'path': {'d': 'M17 21h2a2 2 0 0 0 2-2'}}, {'path': {'d': 'M21 12v3'}}, {'path': {'d': 'm21 3-5 5'}}, {'path': {'d': 'M3 7V5a2 2 0 0 1 2-2'}}, {'path': {'d': 'm5 21 4.144-4.144a1.21 1.21 0 0 1 1.712 0L13 19'}}, {'path': {'d': 'M9 3h3'}}, {'rect': {'x': '3', 'y': '11', 'width': '10', 'height': '10', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Cake(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-cake'], 'items': [{'path': {'d': 'M20 21v-8a2 2 0 0 0-2-2H6a2 2 0 0 0-2 2v8'}}, {'path': {'d': 'M4 16s.5-1 2-1 2.5 2 4 2 2.5-2 4-2 2.5 2 4 2 2-1 2-1'}}, {'path': {'d': 'M2 21h20'}}, {'path': {'d': 'M7 8v3'}}, {'path': {'d': 'M12 8v3'}}, {'path': {'d': 'M17 8v3'}}, {'path': {'d': 'M7 4h.01'}}, {'path': {'d': 'M12 4h.01'}}, {'path': {'d': 'M17 4h.01'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ListTodo(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-list-todo'], 'items': [{'path': {'d': 'M13 5h8'}}, {'path': {'d': 'M13 12h8'}}, {'path': {'d': 'M13 19h8'}}, {'path': {'d': 'm3 17 2 2 4-4'}}, {'rect': {'x': '3', 'y': '4', 'width': '6', 'height': '6', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def KeyboardMusic(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-keyboard-music'], 'items': [{'rect': {'width': '20', 'height': '16', 'x': '2', 'y': '4', 'rx': '2'}}, {'path': {'d': 'M6 8h4'}}, {'path': {'d': 'M14 8h.01'}}, {'path': {'d': 'M18 8h.01'}}, {'path': {'d': 'M2 12h20'}}, {'path': {'d': 'M6 12v4'}}, {'path': {'d': 'M10 12v4'}}, {'path': {'d': 'M14 12v4'}}, {'path': {'d': 'M18 12v4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MoveHorizontal(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-move-horizontal'], 'items': [{'path': {'d': 'm18 8 4 4-4 4'}}, {'path': {'d': 'M2 12h20'}}, {'path': {'d': 'm6 8-4 4 4 4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BookLock(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-book-lock'], 'items': [{'path': {'d': 'M18 6V4a2 2 0 1 0-4 0v2'}}, {'path': {'d': 'M20 15v6a1 1 0 0 1-1 1H6.5a1 1 0 0 1 0-5H20'}}, {'path': {'d': 'M4 19.5v-15A2.5 2.5 0 0 1 6.5 2H10'}}, {'rect': {'x': '12', 'y': '6', 'width': '8', 'height': '5', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Ampersand(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-ampersand'], 'items': [{'path': {'d': 'M16 12h3'}}, {'path': {'d': 'M17.5 12a8 8 0 0 1-8 8A4.5 4.5 0 0 1 5 15.5c0-6 8-4 8-8.5a3 3 0 1 0-6 0c0 3 2.5 8.5 12 13'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Helicopter(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-helicopter'], 'items': [{'path': {'d': 'M11 17v4'}}, {'path': {'d': 'M14 3v8a2 2 0 0 0 2 2h5.865'}}, {'path': {'d': 'M17 17v4'}}, {'path': {'d': 'M18 17a4 4 0 0 0 4-4 8 6 0 0 0-8-6 6 5 0 0 0-6 5v3a2 2 0 0 0 2 2z'}}, {'path': {'d': 'M2 10v5'}}, {'path': {'d': 'M6 3h16'}}, {'path': {'d': 'M7 21h14'}}, {'path': {'d': 'M8 13H2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MountainSnow(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-mountain-snow'], 'items': [{'path': {'d': 'm8 3 4 8 5-5 5 15H2L8 3z'}}, {'path': {'d': 'M4.14 15.08c2.62-1.57 5.24-1.43 7.86.42 2.74 1.94 5.49 2 8.23.19'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def StepBack(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-step-back'], 'items': [{'path': {'d': 'M13.971 4.285A2 2 0 0 1 17 6v12a2 2 0 0 1-3.029 1.715l-9.997-5.998a2 2 0 0 1-.003-3.432z'}}, {'path': {'d': 'M21 20V4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Ampersands(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-ampersands'], 'items': [{'path': {'d': 'M10 17c-5-3-7-7-7-9a2 2 0 0 1 4 0c0 2.5-5 2.5-5 6 0 1.7 1.3 3 3 3 2.8 0 5-2.2 5-5'}}, {'path': {'d': 'M22 17c-5-3-7-7-7-9a2 2 0 0 1 4 0c0 2.5-5 2.5-5 6 0 1.7 1.3 3 3 3 2.8 0 5-2.2 5-5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Usb(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-usb'], 'items': [{'circle': {'cx': '10', 'cy': '7', 'r': '1'}}, {'circle': {'cx': '4', 'cy': '20', 'r': '1'}}, {'path': {'d': 'M4.7 19.3 19 5'}}, {'path': {'d': 'm21 3-3 1 2 2Z'}}, {'path': {'d': 'M9.26 7.68 5 12l2 5'}}, {'path': {'d': 'm10 14 5 2 3.5-3.5'}}, {'path': {'d': 'm18 12 1-1 1 1-1 1Z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def LightbulbOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-lightbulb-off'], 'items': [{'path': {'d': 'M16.8 11.2c.8-.9 1.2-2 1.2-3.2a6 6 0 0 0-9.3-5'}}, {'path': {'d': 'm2 2 20 20'}}, {'path': {'d': 'M6.3 6.3a4.67 4.67 0 0 0 1.2 5.2c.7.7 1.3 1.5 1.5 2.5'}}, {'path': {'d': 'M9 18h6'}}, {'path': {'d': 'M10 22h4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BotOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bot-off'], 'items': [{'path': {'d': 'M13.67 8H18a2 2 0 0 1 2 2v4.33'}}, {'path': {'d': 'M2 14h2'}}, {'path': {'d': 'M20 14h2'}}, {'path': {'d': 'M22 22 2 2'}}, {'path': {'d': 'M8 8H6a2 2 0 0 0-2 2v8a2 2 0 0 0 2 2h12a2 2 0 0 0 1.414-.586'}}, {'path': {'d': 'M9 13v2'}}, {'path': {'d': 'M9.67 4H12v2.33'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Stamp(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-stamp'], 'items': [{'path': {'d': 'M14 13V8.5C14 7 15 7 15 5a3 3 0 0 0-6 0c0 2 1 2 1 3.5V13'}}, {'path': {'d': 'M20 15.5a2.5 2.5 0 0 0-2.5-2.5h-11A2.5 2.5 0 0 0 4 15.5V17a1 1 0 0 0 1 1h14a1 1 0 0 0 1-1z'}}, {'path': {'d': 'M5 22h14'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SearchCode(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-search-code'], 'items': [{'path': {'d': 'm13 13.5 2-2.5-2-2.5'}}, {'path': {'d': 'm21 21-4.3-4.3'}}, {'path': {'d': 'M9 8.5 7 11l2 2.5'}}, {'circle': {'cx': '11', 'cy': '11', 'r': '8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CircleStop(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-circle-stop'], 'items': [{'circle': {'cx': '12', 'cy': '12', 'r': '10'}}, {'rect': {'x': '9', 'y': '9', 'width': '6', 'height': '6', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def HousePlug(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-house-plug'], 'items': [{'path': {'d': 'M10 12V8.964'}}, {'path': {'d': 'M14 12V8.964'}}, {'path': {'d': 'M15 12a1 1 0 0 1 1 1v2a2 2 0 0 1-2 2h-4a2 2 0 0 1-2-2v-2a1 1 0 0 1 1-1z'}}, {'path': {'d': 'M8.5 21H5a2 2 0 0 1-2-2v-9a2 2 0 0 1 .709-1.528l7-6a2 2 0 0 1 2.582 0l7 6A2 2 0 0 1 21 10v9a2 2 0 0 1-2 2h-5a2 2 0 0 1-2-2v-2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ClosedCaption(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-closed-caption'], 'items': [{'path': {'d': 'M10 9.17a3 3 0 1 0 0 5.66'}}, {'path': {'d': 'M17 9.17a3 3 0 1 0 0 5.66'}}, {'rect': {'x': '2', 'y': '5', 'width': '20', 'height': '14', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CircuitBoard(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-circuit-board'], 'items': [{'rect': {'width': '18', 'height': '18', 'x': '3', 'y': '3', 'rx': '2'}}, {'path': {'d': 'M11 9h4a2 2 0 0 0 2-2V3'}}, {'circle': {'cx': '9', 'cy': '9', 'r': '2'}}, {'path': {'d': 'M7 21v-4a2 2 0 0 1 2-2h4'}}, {'circle': {'cx': '15', 'cy': '15', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Diamond(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-diamond'], 'items': [{'path': {'d': 'M2.7 10.3a2.41 2.41 0 0 0 0 3.41l7.59 7.59a2.41 2.41 0 0 0 3.41 0l7.59-7.59a2.41 2.41 0 0 0 0-3.41l-7.59-7.59a2.41 2.41 0 0 0-3.41 0Z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquareCheckBig(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-check-big'], 'items': [{'path': {'d': 'M21 10.656V19a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h12.344'}}, {'path': {'d': 'm9 11 3 3L22 4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BellPlus(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bell-plus'], 'items': [{'path': {'d': 'M10.268 21a2 2 0 0 0 3.464 0'}}, {'path': {'d': 'M15 8h6'}}, {'path': {'d': 'M18 5v6'}}, {'path': {'d': 'M20.002 14.464a9 9 0 0 0 .738.863A1 1 0 0 1 20 17H4a1 1 0 0 1-.74-1.673C4.59 13.956 6 12.499 6 8a6 6 0 0 1 8.75-5.332'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SwatchBook(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-swatch-book'], 'items': [{'path': {'d': 'M11 17a4 4 0 0 1-8 0V5a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2Z'}}, {'path': {'d': 'M16.7 13H19a2 2 0 0 1 2 2v4a2 2 0 0 1-2 2H7'}}, {'path': {'d': 'M 7 17h.01'}}, {'path': {'d': 'm11 8 2.3-2.3a2.4 2.4 0 0 1 3.404.004L18.6 7.6a2.4 2.4 0 0 1 .026 3.434L9.9 19.8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FishSymbol(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-fish-symbol'], 'items': [{'path': {'d': 'M2 16s9-15 20-4C11 23 2 8 2 8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ChartNoAxesColumn(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-chart-no-axes-column'], 'items': [{'path': {'d': 'M5 21v-6'}}, {'path': {'d': 'M12 21V3'}}, {'path': {'d': 'M19 21V9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Twitter(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-twitter'], 'items': [{'path': {'d': 'M22 4s-.7 2.1-2 3.4c1.6 10-9.4 17.3-18 11.6 2.2.1 4.4-.6 6-2C3 15.5.5 9.6 3 5c2.2 2.6 5.6 4.1 9 4-.9-4.2 4-6.6 7-3.8 1.1 0 3-1.2 3-1.2z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MailWarning(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-mail-warning'], 'items': [{'path': {'d': 'M22 10.5V6a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v12c0 1.1.9 2 2 2h12.5'}}, {'path': {'d': 'm22 7-8.97 5.7a1.94 1.94 0 0 1-2.06 0L2 7'}}, {'path': {'d': 'M20 14v4'}}, {'path': {'d': 'M20 22v.01'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Trees(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-trees'], 'items': [{'path': {'d': 'M10 10v.2A3 3 0 0 1 8.9 16H5a3 3 0 0 1-1-5.8V10a3 3 0 0 1 6 0Z'}}, {'path': {'d': 'M7 16v6'}}, {'path': {'d': 'M13 19v3'}}, {'path': {'d': 'M12 19h8.3a1 1 0 0 0 .7-1.7L18 14h.3a1 1 0 0 0 .7-1.7L16 9h.2a1 1 0 0 0 .8-1.7L13 3l-1.4 1.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Construction(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-construction'], 'items': [{'rect': {'x': '2', 'y': '6', 'width': '20', 'height': '8', 'rx': '1'}}, {'path': {'d': 'M17 14v7'}}, {'path': {'d': 'M7 14v7'}}, {'path': {'d': 'M17 3v3'}}, {'path': {'d': 'M7 3v3'}}, {'path': {'d': 'M10 14 2.3 6.3'}}, {'path': {'d': 'm14 6 7.7 7.7'}}, {'path': {'d': 'm8 6 8 8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MoveVertical(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-move-vertical'], 'items': [{'path': {'d': 'M12 2v20'}}, {'path': {'d': 'm8 18 4 4 4-4'}}, {'path': {'d': 'm8 6 4-4 4 4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CloudSunRain(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-cloud-sun-rain'], 'items': [{'path': {'d': 'M12 2v2'}}, {'path': {'d': 'm4.93 4.93 1.41 1.41'}}, {'path': {'d': 'M20 12h2'}}, {'path': {'d': 'm19.07 4.93-1.41 1.41'}}, {'path': {'d': 'M15.947 12.65a4 4 0 0 0-5.925-4.128'}}, {'path': {'d': 'M3 20a5 5 0 1 1 8.9-4H13a3 3 0 0 1 2 5.24'}}, {'path': {'d': 'M11 20v2'}}, {'path': {'d': 'M7 19v2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def House(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-house'], 'items': [{'path': {'d': 'M15 21v-8a1 1 0 0 0-1-1h-4a1 1 0 0 0-1 1v8'}}, {'path': {'d': 'M3 10a2 2 0 0 1 .709-1.528l7-6a2 2 0 0 1 2.582 0l7 6A2 2 0 0 1 21 10v9a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def GlobeLock(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-globe-lock'], 'items': [{'path': {'d': 'M15.686 15A14.5 14.5 0 0 1 12 22a14.5 14.5 0 0 1 0-20 10 10 0 1 0 9.542 13'}}, {'path': {'d': 'M2 12h8.5'}}, {'path': {'d': 'M20 6V4a2 2 0 1 0-4 0v2'}}, {'rect': {'width': '8', 'height': '5', 'x': '14', 'y': '6', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def LoaderCircle(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-loader-circle'], 'items': [{'path': {'d': 'M21 12a9 9 0 1 1-6.219-8.56'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Bold(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bold'], 'items': [{'path': {'d': 'M6 12h9a4 4 0 0 1 0 8H7a1 1 0 0 1-1-1V5a1 1 0 0 1 1-1h7a4 4 0 0 1 0 8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TextCursorInput(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-text-cursor-input'], 'items': [{'path': {'d': 'M12 20h-1a2 2 0 0 1-2-2 2 2 0 0 1-2 2H6'}}, {'path': {'d': 'M13 8h7a2 2 0 0 1 2 2v4a2 2 0 0 1-2 2h-7'}}, {'path': {'d': 'M5 16H4a2 2 0 0 1-2-2v-4a2 2 0 0 1 2-2h1'}}, {'path': {'d': 'M6 4h1a2 2 0 0 1 2 2 2 2 0 0 1 2-2h1'}}, {'path': {'d': 'M9 6v12'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Torus(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-torus'], 'items': [{'ellipse': {'cx': '12', 'cy': '11', 'rx': '3', 'ry': '2'}}, {'ellipse': {'cx': '12', 'cy': '12.5', 'rx': '10', 'ry': '8.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Video(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-video'], 'items': [{'path': {'d': 'm16 13 5.223 3.482a.5.5 0 0 0 .777-.416V7.87a.5.5 0 0 0-.752-.432L16 10.5'}}, {'rect': {'x': '2', 'y': '6', 'width': '14', 'height': '12', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TicketsPlane(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-tickets-plane'], 'items': [{'path': {'d': 'M10.5 17h1.227a2 2 0 0 0 1.345-.52L18 12'}}, {'path': {'d': 'm12 13.5 3.75.5'}}, {'path': {'d': 'm4.5 8 10.58-5.06a1 1 0 0 1 1.342.488L18.5 8'}}, {'path': {'d': 'M6 10V8'}}, {'path': {'d': 'M6 14v1'}}, {'path': {'d': 'M6 19v2'}}, {'rect': {'x': '2', 'y': '8', 'width': '20', 'height': '13', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def RectangleEllipsis(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-rectangle-ellipsis'], 'items': [{'rect': {'width': '20', 'height': '12', 'x': '2', 'y': '6', 'rx': '2'}}, {'path': {'d': 'M12 12h.01'}}, {'path': {'d': 'M17 12h.01'}}, {'path': {'d': 'M7 12h.01'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ALargeSmall(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-a-large-small'], 'items': [{'path': {'d': 'm15 16 2.536-7.328a1.02 1.02 1 0 1 1.928 0L22 16'}}, {'path': {'d': 'M15.697 14h5.606'}}, {'path': {'d': 'm2 16 4.039-9.69a.5.5 0 0 1 .923 0L11 16'}}, {'path': {'d': 'M3.304 13h6.392'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Pi(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-pi'], 'items': [{'line': {'x1': '9', 'x2': '9', 'y1': '4', 'y2': '20'}}, {'path': {'d': 'M4 7c0-1.7 1.3-3 3-3h13'}}, {'path': {'d': 'M18 20c-1.7 0-3-1.3-3-3V4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TableCellsMerge(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-table-cells-merge'], 'items': [{'path': {'d': 'M12 21v-6'}}, {'path': {'d': 'M12 9V3'}}, {'path': {'d': 'M3 15h18'}}, {'path': {'d': 'M3 9h18'}}, {'rect': {'width': '18', 'height': '18', 'x': '3', 'y': '3', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Scooter(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-scooter'], 'items': [{'path': {'d': 'M21 4h-3.5l2 11.05'}}, {'path': {'d': 'M6.95 17h5.142c.523 0 .95-.406 1.063-.916a6.5 6.5 0 0 1 5.345-5.009'}}, {'circle': {'cx': '19.5', 'cy': '17.5', 'r': '2.5'}}, {'circle': {'cx': '4.5', 'cy': '17.5', 'r': '2.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Eye(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-eye'], 'items': [{'path': {'d': 'M2.062 12.348a1 1 0 0 1 0-.696 10.75 10.75 0 0 1 19.876 0 1 1 0 0 1 0 .696 10.75 10.75 0 0 1-19.876 0'}}, {'circle': {'cx': '12', 'cy': '12', 'r': '3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Share(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-share'], 'items': [{'path': {'d': 'M12 2v13'}}, {'path': {'d': 'm16 6-4-4-4 4'}}, {'path': {'d': 'M4 12v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2v-8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FileTypeCorner(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-file-type-corner'], 'items': [{'path': {'d': 'M12 22h6a2 2 0 0 0 2-2V8a2.4 2.4 0 0 0-.706-1.706l-3.588-3.588A2.4 2.4 0 0 0 14 2H6a2 2 0 0 0-2 2v6'}}, {'path': {'d': 'M14 2v5a1 1 0 0 0 1 1h5'}}, {'path': {'d': 'M3 16v-1.5a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 .5.5V16'}}, {'path': {'d': 'M6 22h2'}}, {'path': {'d': 'M7 14v8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Grid2x2X(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-grid-2x2-x'], 'items': [{'path': {'d': 'M12 3v17a1 1 0 0 1-1 1H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2v6a1 1 0 0 1-1 1H3'}}, {'path': {'d': 'm16 16 5 5'}}, {'path': {'d': 'm16 21 5-5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Variable(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-variable'], 'items': [{'path': {'d': 'M8 21s-4-3-4-9 4-9 4-9'}}, {'path': {'d': 'M16 3s4 3 4 9-4 9-4 9'}}, {'line': {'x1': '15', 'x2': '9', 'y1': '9', 'y2': '15'}}, {'line': {'x1': '9', 'x2': '15', 'y1': '9', 'y2': '15'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CircleChevronUp(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-circle-chevron-up'], 'items': [{'circle': {'cx': '12', 'cy': '12', 'r': '10'}}, {'path': {'d': 'm8 14 4-4 4 4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Tv(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-tv'], 'items': [{'path': {'d': 'm17 2-5 5-5-5'}}, {'rect': {'width': '20', 'height': '15', 'x': '2', 'y': '7', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def HeartPulse(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-heart-pulse'], 'items': [{'path': {'d': 'M2 9.5a5.5 5.5 0 0 1 9.591-3.676.56.56 0 0 0 .818 0A5.49 5.49 0 0 1 22 9.5c0 2.29-1.5 4-3 5.5l-5.492 5.313a2 2 0 0 1-3 .019L5 15c-1.5-1.5-3-3.2-3-5.5'}}, {'path': {'d': 'M3.22 13H9.5l.5-1 2 4.5 2-7 1.5 3.5h5.27'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Group(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-group'], 'items': [{'path': {'d': 'M3 7V5c0-1.1.9-2 2-2h2'}}, {'path': {'d': 'M17 3h2c1.1 0 2 .9 2 2v2'}}, {'path': {'d': 'M21 17v2c0 1.1-.9 2-2 2h-2'}}, {'path': {'d': 'M7 21H5c-1.1 0-2-.9-2-2v-2'}}, {'rect': {'width': '7', 'height': '5', 'x': '7', 'y': '7', 'rx': '1'}}, {'rect': {'width': '7', 'height': '5', 'x': '10', 'y': '12', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Navigation2(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-navigation-2'], 'items': [{'polygon': {'points': '12 2 19 21 12 17 5 21 12 2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MonitorStop(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-monitor-stop'], 'items': [{'path': {'d': 'M12 17v4'}}, {'path': {'d': 'M8 21h8'}}, {'rect': {'x': '2', 'y': '3', 'width': '20', 'height': '14', 'rx': '2'}}, {'rect': {'x': '9', 'y': '7', 'width': '6', 'height': '6', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Turntable(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-turntable'], 'items': [{'path': {'d': 'M10 12.01h.01'}}, {'path': {'d': 'M18 8v4a8 8 0 0 1-1.07 4'}}, {'circle': {'cx': '10', 'cy': '12', 'r': '4'}}, {'rect': {'x': '2', 'y': '4', 'width': '20', 'height': '16', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ScissorsLineDashed(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-scissors-line-dashed'], 'items': [{'path': {'d': 'M5.42 9.42 8 12'}}, {'circle': {'cx': '4', 'cy': '8', 'r': '2'}}, {'path': {'d': 'm14 6-8.58 8.58'}}, {'circle': {'cx': '4', 'cy': '16', 'r': '2'}}, {'path': {'d': 'M10.8 14.8 14 18'}}, {'path': {'d': 'M16 12h-2'}}, {'path': {'d': 'M22 12h-2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Proportions(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-proportions'], 'items': [{'rect': {'width': '20', 'height': '16', 'x': '2', 'y': '4', 'rx': '2'}}, {'path': {'d': 'M12 9v11'}}, {'path': {'d': 'M2 9h13a2 2 0 0 1 2 2v9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Orbit(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-orbit'], 'items': [{'path': {'d': 'M20.341 6.484A10 10 0 0 1 10.266 21.85'}}, {'path': {'d': 'M3.659 17.516A10 10 0 0 1 13.74 2.152'}}, {'circle': {'cx': '12', 'cy': '12', 'r': '3'}}, {'circle': {'cx': '19', 'cy': '5', 'r': '2'}}, {'circle': {'cx': '5', 'cy': '19', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Hospital(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-hospital'], 'items': [{'path': {'d': 'M12 7v4'}}, {'path': {'d': 'M14 21v-3a2 2 0 0 0-4 0v3'}}, {'path': {'d': 'M14 9h-4'}}, {'path': {'d': 'M18 11h2a2 2 0 0 1 2 2v6a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2v-9a2 2 0 0 1 2-2h2'}}, {'path': {'d': 'M18 21V5a2 2 0 0 0-2-2H8a2 2 0 0 0-2 2v16'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def KeyboardOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-keyboard-off'], 'items': [{'path': {'d': 'M 20 4 A2 2 0 0 1 22 6'}}, {'path': {'d': 'M 22 6 L 22 16.41'}}, {'path': {'d': 'M 7 16 L 16 16'}}, {'path': {'d': 'M 9.69 4 L 20 4'}}, {'path': {'d': 'M14 8h.01'}}, {'path': {'d': 'M18 8h.01'}}, {'path': {'d': 'm2 2 20 20'}}, {'path': {'d': 'M20 20H4a2 2 0 0 1-2-2V6a2 2 0 0 1 2-2'}}, {'path': {'d': 'M6 8h.01'}}, {'path': {'d': 'M8 12h.01'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Superscript(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-superscript'], 'items': [{'path': {'d': 'm4 19 8-8'}}, {'path': {'d': 'm12 19-8-8'}}, {'path': {'d': 'M20 12h-4c0-1.5.442-2 1.5-2.5S20 8.334 20 7.002c0-.472-.17-.93-.484-1.29a2.105 2.105 0 0 0-2.617-.436c-.42.239-.738.614-.899 1.06'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ReceiptEuro(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-receipt-euro'], 'items': [{'path': {'d': 'M4 2v20l2-1 2 1 2-1 2 1 2-1 2 1 2-1 2 1V2l-2 1-2-1-2 1-2-1-2 1-2-1-2 1Z'}}, {'path': {'d': 'M8 12h5'}}, {'path': {'d': 'M16 9.5a4 4 0 1 0 0 5.2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SeparatorHorizontal(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-separator-horizontal'], 'items': [{'path': {'d': 'm16 16-4 4-4-4'}}, {'path': {'d': 'M3 12h18'}}, {'path': {'d': 'm8 8 4-4 4 4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CarFront(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-car-front'], 'items': [{'path': {'d': 'm21 8-2 2-1.5-3.7A2 2 0 0 0 15.646 5H8.4a2 2 0 0 0-1.903 1.257L5 10 3 8'}}, {'path': {'d': 'M7 14h.01'}}, {'path': {'d': 'M17 14h.01'}}, {'rect': {'width': '18', 'height': '8', 'x': '3', 'y': '10', 'rx': '2'}}, {'path': {'d': 'M5 18v2'}}, {'path': {'d': 'M19 18v2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ArrowUpToLine(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-arrow-up-to-line'], 'items': [{'path': {'d': 'M5 3h14'}}, {'path': {'d': 'm18 13-6-6-6 6'}}, {'path': {'d': 'M12 7v14'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MailOpen(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-mail-open'], 'items': [{'path': {'d': 'M21.2 8.4c.5.38.8.97.8 1.6v10a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V10a2 2 0 0 1 .8-1.6l8-6a2 2 0 0 1 2.4 0l8 6Z'}}, {'path': {'d': 'm22 10-8.97 5.7a1.94 1.94 0 0 1-2.06 0L2 10'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ArrowBigUpDash(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-arrow-big-up-dash'], 'items': [{'path': {'d': 'M9 13a1 1 0 0 0-1-1H5.061a1 1 0 0 1-.75-1.811l6.836-6.835a1.207 1.207 0 0 1 1.707 0l6.835 6.835a1 1 0 0 1-.75 1.811H16a1 1 0 0 0-1 1v2a1 1 0 0 1-1 1h-4a1 1 0 0 1-1-1z'}}, {'path': {'d': 'M9 20h6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Command(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-command'], 'items': [{'path': {'d': 'M15 6v12a3 3 0 1 0 3-3H6a3 3 0 1 0 3 3V6a3 3 0 1 0-3 3h12a3 3 0 1 0-3-3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CircleCheckBig(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-circle-check-big'], 'items': [{'path': {'d': 'M21.801 10A10 10 0 1 1 17 3.335'}}, {'path': {'d': 'm9 11 3 3L22 4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Rss(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-rss'], 'items': [{'path': {'d': 'M4 11a9 9 0 0 1 9 9'}}, {'path': {'d': 'M4 4a16 16 0 0 1 16 16'}}, {'circle': {'cx': '5', 'cy': '19', 'r': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Import(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-import'], 'items': [{'path': {'d': 'M12 3v12'}}, {'path': {'d': 'm8 11 4 4 4-4'}}, {'path': {'d': 'M8 5H4a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2V7a2 2 0 0 0-2-2h-4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def RulerDimensionLine(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-ruler-dimension-line'], 'items': [{'path': {'d': 'M10 15v-3'}}, {'path': {'d': 'M14 15v-3'}}, {'path': {'d': 'M18 15v-3'}}, {'path': {'d': 'M2 8V4'}}, {'path': {'d': 'M22 6H2'}}, {'path': {'d': 'M22 8V4'}}, {'path': {'d': 'M6 15v-3'}}, {'rect': {'x': '2', 'y': '12', 'width': '20', 'height': '8', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Mountain(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-mountain'], 'items': [{'path': {'d': 'm8 3 4 8 5-5 5 15H2L8 3z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def IceCreamBowl(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-ice-cream-bowl'], 'items': [{'path': {'d': 'M12 17c5 0 8-2.69 8-6H4c0 3.31 3 6 8 6m-4 4h8m-4-3v3M5.14 11a3.5 3.5 0 1 1 6.71 0'}}, {'path': {'d': 'M12.14 11a3.5 3.5 0 1 1 6.71 0'}}, {'path': {'d': 'M15.5 6.5a3.5 3.5 0 1 0-7 0'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def HeartMinus(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-heart-minus'], 'items': [{'path': {'d': 'm14.876 18.99-1.368 1.323a2 2 0 0 1-3 .019L5 15c-1.5-1.5-3-3.2-3-5.5a5.5 5.5 0 0 1 9.591-3.676.56.56 0 0 0 .818 0A5.49 5.49 0 0 1 22 9.5a5.2 5.2 0 0 1-.244 1.572'}}, {'path': {'d': 'M15 15h6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def GitBranchPlus(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-git-branch-plus'], 'items': [{'path': {'d': 'M6 3v12'}}, {'path': {'d': 'M18 9a3 3 0 1 0 0-6 3 3 0 0 0 0 6z'}}, {'path': {'d': 'M6 21a3 3 0 1 0 0-6 3 3 0 0 0 0 6z'}}, {'path': {'d': 'M15 6a9 9 0 0 0-9 9'}}, {'path': {'d': 'M18 15v6'}}, {'path': {'d': 'M21 18h-6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def AlignHorizontalDistributeCenter(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-align-horizontal-distribute-center'], 'items': [{'rect': {'width': '6', 'height': '14', 'x': '4', 'y': '5', 'rx': '2'}}, {'rect': {'width': '6', 'height': '10', 'x': '14', 'y': '7', 'rx': '2'}}, {'path': {'d': 'M17 22v-5'}}, {'path': {'d': 'M17 7V2'}}, {'path': {'d': 'M7 22v-3'}}, {'path': {'d': 'M7 5V2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MousePointer(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-mouse-pointer'], 'items': [{'path': {'d': 'M12.586 12.586 19 19'}}, {'path': {'d': 'M3.688 3.037a.497.497 0 0 0-.651.651l6.5 15.999a.501.501 0 0 0 .947-.062l1.569-6.083a2 2 0 0 1 1.448-1.479l6.124-1.579a.5.5 0 0 0 .063-.947z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
